@@ -5,7 +5,7 @@
 #  open source, and has the attribution requirements (GPL Section 7) at
 #  http://statnet.org/attribution
 #
-#  Copyright 2007-2018 Statnet Commons
+#  Copyright 2007-2019 Statnet Commons
 #######################################################################
 ## Concatenate a character list with commas and ands in the right places.
 
@@ -42,7 +42,7 @@ paste.and <- function(x, oq='', cq='', con='and'){
   if(length(x)==0) return('')
   if(length(x)==1) return(x)
   if(length(x)==2) return(paste(x[1],con,x[2]))
-  if(length(x)>=3) return(paste0(paste(x[-length(x)], collapse=", "),', ',con,' ',x[length(x)]))
+  if(length(x)>=3) return(paste0(paste(x[-length(x)], collapse=", "),', ',con,' ',ult(x)))
 }
 
 
